Stan Math Library: stan/math/rev/core/std_isnan.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
std_isnan.hpp File Reference
`#include <stan/math/rev/core/var.hpp>`
`#include <cmath>`

Go to the source code of this file.

## Namespaces
| std

## Functions
int | std::isnan (const stan::math::var &a)
| Checks if the given number is NaN. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.